/*******************************************************************************
 * Copyright 2015 - 2019 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.assistant;

import org.apache.commons.lang.StringUtils;
import org.eclipse.swt.widgets.Composite;

import de.frankmuenster.mahoe.utils.I18N;
import de.willuhn.jameica.gui.Action;
import de.willuhn.jameica.gui.dialogs.AbstractDialog;
import de.willuhn.jameica.gui.input.TextAreaInput;
import de.willuhn.jameica.gui.input.TextInput;
import de.willuhn.jameica.gui.parts.ButtonArea;
import de.willuhn.jameica.gui.util.Container;
import de.willuhn.jameica.gui.util.SimpleContainer;
import de.willuhn.jameica.system.OperationCanceledException;
import de.willuhn.util.ApplicationException;

/**
 * Abstrakter Konto-Anlageassistenten-Dialog. Zeichnet die allgemeinen Inputfelder und die Buttons.
 *
 * @author Frank Mnster
 * @param <T>
 *            die bankspezifischen CreateAccountInfos
 */
public abstract class AbstractCreateAccountDialog<T extends CreateInfo> extends AbstractDialog<T> {

    /**
     * Kontoinhaber Input
     */
    protected transient TextInput accOwner;

    /**
     * Bezeichnung Input
     */
    protected transient TextInput accDescription;

    /**
     * Kommentar Input
     */
    protected transient TextAreaInput accComment;

    /**
     * Login Input
     */

    /**
     * Die allg. Kontoinformationen
     */
    private CreateInfo info;

    /**
     * Container fr die Inputfelder
     */
    protected transient Container container;

    /**
     * Die Rckgabe-Daten
     */
    protected T data;

    /**
     */
    public AbstractCreateAccountDialog() {

        super(AbstractDialog.POSITION_CENTER);
        this.setSize(550, 400);
    }

    /**
     * @see de.willuhn.jameica.gui.dialogs.AbstractDialog#paint(org.eclipse.swt.widgets.Composite)
     */
    @Override
    protected void paint(final Composite parent) {

        // Erstelle einfachen Container
        this.container = new SimpleContainer(parent, true, 2);

        this.accOwner = new TextInput(StringUtils.EMPTY, 20, "Kontoinhaber"); //$NON-NLS-1$
        this.accOwner.setComment(StringUtils.EMPTY);
        this.accOwner.setMandatory(true);
        this.accDescription = new TextInput(StringUtils.EMPTY, 60, "Beschreibung"); //$NON-NLS-1$
        this.accComment = new TextAreaInput(StringUtils.EMPTY, 100);

        this.container.addLabelPair(I18N.tr("AbstractCreateAccountDialog.accountOwner"), this.accOwner); //$NON-NLS-1$
        this.container.addLabelPair(I18N.tr("AbstractCreateAccountDialog.description"), this.accDescription); //$NON-NLS-1$
        this.container.addLabelPair(I18N.tr("AbstractCreateAccountDialog.comment"), this.accComment); //$NON-NLS-1$

        final ButtonArea buttons = new ButtonArea();
        buttons.addButton(I18N.tr("AbstractCreateAccountDialog.createAccountBtn"), new Action() { //$NON-NLS-1$

            /**
             * @see de.willuhn.jameica.gui.Action#handleAction(java.lang.Object)
             */
            @Override
            public void handleAction(final Object context) throws ApplicationException {

                boolean dataOk = true;

                AbstractCreateAccountDialog.this.info = new CreateInfo();
                AbstractCreateAccountDialog.this.info
                        .setOwner((String) AbstractCreateAccountDialog.this.accOwner.getValue());
                AbstractCreateAccountDialog.this.info
                        .setDescription((String) AbstractCreateAccountDialog.this.accDescription.getValue());
                AbstractCreateAccountDialog.this.info
                        .setComment((String) AbstractCreateAccountDialog.this.accComment.getValue());

                if (StringUtils.isEmpty(AbstractCreateAccountDialog.this.info.getOwner())) {
                    dataOk = false;
                    AbstractCreateAccountDialog.this.accOwner
                            .setComment(I18N.tr("AbstractCreateAccountDialog.accountOwnerMandatory")); //$NON-NLS-1$
                } else {
                    AbstractCreateAccountDialog.this.accOwner.setComment(StringUtils.EMPTY);
                }
                dataOk = AbstractCreateAccountDialog.this.prepareData() && dataOk;
                if (dataOk) {
                    AbstractCreateAccountDialog.this.close();
                }
            }
        }, null, true, "document-save.png"); //$NON-NLS-1$
        // Abbrechen Button einfgen
        buttons.addButton(I18N.tr("_cancel"), new Action() { //$NON-NLS-1$

            /**
             * @see de.willuhn.jameica.gui.Action#handleAction(java.lang.Object)
             */
            @Override
            public void handleAction(final Object context) throws ApplicationException {

                throw new OperationCanceledException();
            }
        }, null, false, "process-stop.png"); //$NON-NLS-1$

        // Erstelle einfachen Container
        final SimpleContainer containerButons = new SimpleContainer(parent, true, 2);
        containerButons.addButtonArea(buttons);

    }

    /**
     * @see de.willuhn.jameica.gui.dialogs.AbstractDialog#getData()
     */
    @SuppressWarnings("unchecked")
    @Override
    protected T getData() {

        return (T) this.info;
    }

    /**
     * Muss vom Unterklasse implementiert werden. Dort mssen die Daten fr die Funktion getData() vorbereitet werden.
     *
     * @return <i>true</i>, wenn alles in Ordnung ist, <i>false</i> falls Eingabedaten fehlen oder falsch sind.
     */
    protected abstract boolean prepareData();

}
