
package de.frankmuenster.mahoe.banks.bsh.json;

import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

/**
 * JSON Nachricht Objekt
 *
 * @author Frank Mnster
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({ "id", "date", "title", "type", "read", "text", "deletable", "nbaurl", "typeName" })
public class Message {

    /**
     * Nachrichten ID
     */
    @JsonProperty("id")
    private String id; // NOPMD

    /**
     * Datum der Nachricht
     */
    @JsonProperty("date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "dd.MM.yyyy", timezone = "CET")
    private Date date;

    /**
     * Titel/Subject der Nachricht
     */
    @JsonProperty("title")
    private String title;

    /**
     * Der Type der Nachricht
     */
    @JsonProperty("type")
    private String type;

    /**
     * Nachricht schon gelsen
     */
    @JsonProperty("read")
    private Boolean read;

    /**
     * Nachrichtentext
     */
    @JsonProperty("text")
    private String text;

    /**
     * Nachrichtentyp
     */
    @JsonProperty("typeName")
    private String typeName;

    /**
     * Kann die Nachricht gelsht werden
     */
    @JsonProperty("deletable")
    private Boolean deletable;

    /**
     * Werbe-URL
     */
    @JsonProperty("nbaurl")
    private String nbaurl;

    /**
     * Standardkonstruktor
     */
    public Message() {
        // Absichtlich leer
    }

    /**
     * Liefert das Datum
     *
     * @return das Datum
     */
    @JsonProperty("date")
    public Date getDate() {

        return this.date;
    }

    /**
     * Liefert die ID
     *
     * @return die ID
     */
    @JsonProperty("id")
    public String getId() {

        return this.id;
    }

    /**
     * Liefert die Werbe-URL. Wir hier wohl nicht benutzt.
     *
     * @return die Werbe-URL
     */
    @JsonProperty("nbaurl")
    public String getNbaurl() {

        return this.nbaurl;
    }

    /**
     * Liefert den Text der Nachricht.
     *
     * @return den Text
     */
    @JsonProperty("text")
    public String getText() {

        return this.text;
    }

    /**
     * Liefert den Titel
     *
     * @return den Titel
     */
    @JsonProperty("title")
    public String getTitle() {

        return this.title;
    }

    /**
     * Liefert den Typ
     *
     * @return den Typ
     */
    @JsonProperty("type")
    public String getType() {

        return this.type;
    }

    /**
     * Liefert den Nachrichtentyp
     *
     * @return den Nachrichtentyp
     */
    @JsonProperty("typeName")
    public String getTypeName() {

        return this.typeName;
    }

    /**
     * Kann die Nachricht gelscht werden.
     *
     * @return <i>true</i>, falls die Nachricht gelscht werden kann,
     *         <i>false</i> sonst.
     */
    @JsonProperty("deletable")
    public Boolean isDeletable() {

        return this.deletable;
    }

    /**
     * Nachricht schon gelesen.
     *
     * @return <i>true</i>, falls die Nachricht schon gelesen ist, <i>false</i>
     *         sonst.
     */
    @JsonProperty("read")
    public Boolean isRead() {

        return this.read;
    }

}
