/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.banks.santander.assistant;

import java.rmi.RemoteException;

import org.apache.commons.lang.StringUtils;

import de.frankmuenster.mahoe.MahoeSynchronizeBackend;
import de.frankmuenster.mahoe.assistant.AbstractCreateAccountAssistant;
import de.frankmuenster.mahoe.assistant.CreateAccountException;
import de.frankmuenster.mahoe.banks.santander.SantanderBank;
import de.frankmuenster.mahoe.utils.Utils;
import de.willuhn.jameica.hbci.rmi.Konto;
import de.willuhn.jameica.hbci.rmi.KontoType;
import de.willuhn.util.ApplicationException;

/**
 * Santander Konto-Anlagen-Assistent
 *
 * @author Frank Mnster
 */
public class SantanderCreateAccountAssistent
        extends AbstractCreateAccountAssistant<SantanderCreateInfo, SantanderCreateAccountDialog> {

    /**
     * Standardkonstruktor
     */
    public SantanderCreateAccountAssistent() {
        super();
    }

    /**
     * @see AbstractCreateAccountAssistant#getDialog()
     */
    @Override
    public SantanderCreateAccountDialog getDialog() throws CreateAccountException {
        return new SantanderCreateAccountDialog();
    }

    /**
     * @see AbstractCreateAccountAssistant#setBankSpecificMetaData(de.frankmuenster.mahoe.assistant.CreateInfo,
     *      Konto)
     */
    @Override
    public void setBankSpecificMetaData(final SantanderCreateInfo info, final Konto konto)
            throws RemoteException, ApplicationException {

        konto.setMeta(MahoeSynchronizeBackend.BANK_NAME, SantanderBank.NAME);
        if (info.getAccountType().equals(KontoType.GIRO)) {
            konto.setMeta(MahoeSynchronizeBackend.KONTO_VERSION, SantanderBank.KTO_VER_GIRO);
            konto.setMeta(MahoeSynchronizeBackend.CARD_NUMBER, StringUtils.EMPTY);
            konto.setMeta(MahoeSynchronizeBackend.CARD_COMPANY, StringUtils.EMPTY);
            // Ausgleichbuchung
            konto.setMeta(MahoeSynchronizeBackend.CREATE_CLEARING, Utils.TEXT_NEIN);
            konto.setMeta(MahoeSynchronizeBackend.CLEARING_ACCOUNT, StringUtils.EMPTY);
        } else {
            konto.setMeta(MahoeSynchronizeBackend.KONTO_VERSION, SantanderBank.KTO_VER_KREDIT);
            konto.setMeta(MahoeSynchronizeBackend.CARD_NUMBER, info.getKtoNummer());
            konto.setMeta(MahoeSynchronizeBackend.CARD_COMPANY, StringUtils.EMPTY);
            // Ausgleichbuchung
            final String createClearing = info.isCreateClearing() ? Utils.TEXT_JA : Utils.TEXT_NEIN;
            konto.setMeta(MahoeSynchronizeBackend.CREATE_CLEARING, createClearing);
            if (info.isCreateClearing()) {
                konto.setMeta(MahoeSynchronizeBackend.CLEARING_ACCOUNT, info.getClearingAccount().getID());
            }
        }

    }

    @Override
    protected void setBankSpecificAccountParameter(final Konto account, final SantanderCreateInfo info)
            throws RemoteException {

        String accountNbr;
        if (info.getAccountType().equals(KontoType.GIRO)) {
            accountNbr = info.getKtoNummer();
        } else {
            accountNbr = info.getKtoNummer().substring(6, 15);
        }
        account.setBLZ(SantanderBank.BLZ);
        account.setKontonummer(accountNbr);
        account.setKundennummer(info.getLogin());

        account.setUnterkonto(StringUtils.EMPTY);

    }

}
