/*******************************************************************************
 * Copyright 2015 - 2020 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.banks.santander.jobs;

import java.util.Arrays;

import de.frankmuenster.mahoe.banks.santander.SantanderBank;
import de.frankmuenster.mahoe.banks.santander.web.SantanderWebAccountInformation;
import de.frankmuenster.mahoe.banks.santander.web.SantanderWebSite;
import de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszugPdf;
import de.frankmuenster.mahoe.jobs.InterfaceMahoeSynchronizeJob;
import de.frankmuenster.mahoe.utils.PasswdCache;
import de.frankmuenster.mahoe.web.WebSiteException;
import de.willuhn.util.ApplicationException;

/**
 * Job to download account statements from the Santander Bank.
 *
 * @author Frank Mnster
 */
public class SantanderSynchronizeJobKontoauszugPDF
        extends AbstractMahoeSynchronizeJobKontoauszugPdf<SantanderWebAccountInformation>
        implements InterfaceMahoeSynchronizeJob {

    /**
     * Standard constructor
     */
    public SantanderSynchronizeJobKontoauszugPDF() {

        super();
    }

    /**
     * @see de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszug#getWebSite()
     */
    @Override
    protected void getWebSite() throws WebSiteException, ApplicationException {

        this.webSite = SantanderWebSite.getInstance(this.konto);
    }

    @Override
    protected void login() throws WebSiteException, ApplicationException {

        // Retrieve password from either from cache or ask user
        final char[] password = PasswdCache.getPassword(SantanderBank.WALLET_PREFIX, this.kundennummer);
        // try to login. Error handling is done in WebSite object
        this.webSite.login(password, this.kundennummer);
        // clear password array to be sure
        Arrays.fill(password, ' ');

    }

}
