/*******************************************************************************
 * Copyright 2015 - 2020 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.banks.santander.web;

import java.math.BigDecimal;
import java.rmi.RemoteException;

import de.frankmuenster.mahoe.MahoeSynchronizeBackend;
import de.frankmuenster.mahoe.utils.I18N;
import de.frankmuenster.mahoe.web.AbstractWebAccountInformation;
import de.willuhn.logging.Logger;
import de.willuhn.util.ApplicationException;
import de.willuhn.util.ProgressMonitor;

/**
 * Zustzliche KOntoinfomrationen der BOS
 *
 * @author Frank Mnster
 */
public class SantanderWebAccountInformation extends AbstractWebAccountInformation {

    /**
     * Habenzinssatz
     */
    private Double interestRate;

    /**
     * Zinsen bis jetzt
     */
    private BigDecimal intersetAmount;

    /**
     * Kartenart
     */
    private String kindOfCard;

    /**
     * Standartkonstruktor
     */
    public SantanderWebAccountInformation() {
        super();
    }

    /**
     * @return the interestRate
     */
    public Double getInterestRate() {

        return this.interestRate;
    }

    /**
     * @return the intersetAmount
     */
    public BigDecimal getIntersetAmount() {

        return this.intersetAmount;
    }

    /**
     * @return the kindOfCard
     */
    public String getKindOfCard() {

        return this.kindOfCard;
    }

    /**
     * @param interestRate
     *            the interestRate to set
     */
    public void setInterestRate(final Double interestRate) {

        this.interestRate = interestRate;
    }

    /**
     * @param intersetAmount
     *            the intersetAmount to set
     */
    public void setIntersetAmount(final BigDecimal intersetAmount) {

        this.intersetAmount = intersetAmount;
    }

    /**
     * @param kindOfCard
     *            the kindOfCard to set
     */
    public void setKindOfCard(final String kindOfCard) {

        this.kindOfCard = kindOfCard;
    }

    /**
     * @see de.frankmuenster.mahoe.web.AbstractWebAccountInformation#saveBankSpecificInfo(de.willuhn.util.ProgressMonitor)
     */
    @Override
    protected void saveBankSpecificInfo(final ProgressMonitor monitor) throws ApplicationException {

        // Kartenart
        if (this.kindOfCard != null) {
            monitor.setStatusText(I18N.tr("SantanderWebAccountInformation.updateKindOfCard")); //$NON-NLS-1$
            try {
                this.konto.setMeta(MahoeSynchronizeBackend.CARD_COMPANY, this.kindOfCard);
            } catch (final RemoteException e) {
                Logger.error(I18N.tr("SantanderWebAccountInformation.updateKindOfCardFailed"), e); //$NON-NLS-1$
                throw new ApplicationException(I18N.tr("SantanderWebAccountInformation.updateKindOfCardFailed"), e); //$NON-NLS-1$
            }
        }

    }

}
