/*******************************************************************************
 * Copyright 2015 - 2019 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.banks.targobank.jobs; // NOPMD

import java.util.Arrays;
import java.util.List;

import org.openqa.selenium.WebDriver;

import de.frankmuenster.mahoe.banks.targobank.TargoBank;
import de.frankmuenster.mahoe.banks.targobank.web.TargoBankMessages;
import de.frankmuenster.mahoe.banks.targobank.web.TargoBankWebAccountInformation;
import de.frankmuenster.mahoe.banks.targobank.web.TargoBankWebSite;
import de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszug;
import de.frankmuenster.mahoe.utils.I18N;
import de.frankmuenster.mahoe.utils.PasswdCache;
import de.frankmuenster.mahoe.utils.TransactionSaver;
import de.frankmuenster.mahoe.web.WebSiteException;
import de.frankmuenster.mahoe.web.WebSiteExceptionTypes;
import de.willuhn.jameica.hbci.rmi.Umsatz;
import de.willuhn.logging.Level;
import de.willuhn.logging.Logger;
import de.willuhn.util.ApplicationException;

/**
 * Hier wird die eigentliche Arbeit gemacht.
 *
 * @author Frank Mnster
 */
public class TargoBankSynchronizeJobKontoauszug
        extends AbstractMahoeSynchronizeJobKontoauszug<WebDriver, TargoBankWebAccountInformation, TargoBankMessages> {

    /**
     * Standartkonstruktor
     */
    public TargoBankSynchronizeJobKontoauszug() {

        super();
    }

    /**
     * @see de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszug#getWebSite()
     */
    @Override
    protected void getWebSite() throws WebSiteException, ApplicationException {

        this.webSite = TargoBankWebSite.getInstance(this.konto);
    }

    /**
     * @see de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszug#handleTransactions()
     */
    @Override
    protected void handleTransactions() throws WebSiteException, ApplicationException {

        // Lade vorgemerkte Umstze
        final List<Umsatz> preBooked = this.webSite.getPreBookedTransactions();
        this.monitor.setPercentComplete(30);

        this.monitor.setStatusText(
                I18N.tr("SynchronizeJobKontoauszug.getBooked", this.accountInfo.getLastTransactionDateAsString())); //$NON-NLS-1$
        final List<Umsatz> booked = this.webSite.getBookedTransactions();
        this.monitor.setPercentComplete(40);

        // Debug-Ausgabe
        if (Logger.isLogging(Level.DEBUG)) {
            this.debugLogTransactions(preBooked);
            this.debugLogTransactions(booked);
        }

        // Speicher gebuchte Umstze
        this.monitor.setStatusText(I18N.tr("SynchronizeJobKontoauszug.savingBooked")); //$NON-NLS-1$
        final int bookedCount = TransactionSaver.saveBooked(this.konto, booked);
        this.monitor.setStatusText(I18N.tr("SynchronizeJobKontoauszug.savedBooked", Integer.toString(bookedCount))); //$NON-NLS-1$
        this.monitor.setPercentComplete(50);

        // Speicher vorgemerkte Umstze
        this.monitor.setStatusText(I18N.tr("SynchronizeJobKontoauszug.savingPreBooked")); //$NON-NLS-1$
        final int preBookedCount = TransactionSaver.savePreBooked(this.konto, preBooked);
        this.monitor
                .setStatusText(I18N.tr("SynchronizeJobKontoauszug.savedPreBooked", Integer.toString(preBookedCount))); //$NON-NLS-1$
        this.monitor.setPercentComplete(60);

        Logger.info(I18N.tr("SynchronizeJobKontoauszug.savedPreBooked", Integer.toString(preBookedCount))); //$NON-NLS-1$
        Logger.info(I18N.tr("SynchronizeJobKontoauszug.savedBooked", Integer.toString(bookedCount))); //$NON-NLS-1$

    }

    /**
     * @see de.frankmuenster.mahoe.jobs.AbstractMahoeSynchronizeJobKontoauszug#login()
     */
    @Override
    protected void login() throws WebSiteException, ApplicationException {

        final char[] password = PasswdCache.getPassword(TargoBank.NAME, this.kundennummer);

        try {
            this.webSite.login(password);
        } catch (final WebSiteException e) {
            if (e.getType().equals(WebSiteExceptionTypes.LOGIN_FAILED)) {
                // Passwort zurcksetzten
                PasswdCache.revoke(TargoBank.NAME, this.kundennummer);
            }
            throw e;
        }
        Arrays.fill(password, ' ');

    }

}
