/*******************************************************************************
 * Copyright 2015 - 2019 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.banks.targobank.web;

import java.net.URI;
import java.net.URISyntaxException;
import java.rmi.RemoteException;
import java.util.Date;
import java.util.Map;
import java.util.Map.Entry;

import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;

import com.gargoylesoftware.htmlunit.FailingHttpStatusCodeException;

import de.frankmuenster.mahoe.banks.targobank.TargoBank;
import de.frankmuenster.mahoe.statements.AbstractAccountStatementFinder;
import de.frankmuenster.mahoe.statements.MahoeAccountStatement;
import de.frankmuenster.mahoe.utils.I18N;
import de.frankmuenster.mahoe.utils.WebUtils;
import de.frankmuenster.mahoe.utils.WebUtilsSelenium;
import de.frankmuenster.mahoe.web.WebSiteException;
import de.frankmuenster.mahoe.web.WebSiteExceptionTypes;
import de.willuhn.logging.Logger;

/**
 * Class to get account statements from the banks web page
 *
 * @author Frank Mnster
 */
@SuppressWarnings({ "PMD.ExcessiveImports" })
public class TargoBankAccountStatementFinder
        extends AbstractAccountStatementFinder<WebDriver, TargoBankWebAccountInformation> {

    /**
     * Creates a new TargoBankAccountStatementFinder object with a webClient and
     * account information.
     *
     * @param webClient
     * @param accountInfo
     * @throws WebSiteException
     */
    public TargoBankAccountStatementFinder(final WebDriver webClient, final TargoBankWebAccountInformation accountInfo)
            throws WebSiteException {

        super(webClient, accountInfo);

    }

    /**
     * @throws WebSiteException
     * @see AbstractAccountStatementFinder#startSearch()
     */
    @Override
    protected void startSearch() throws WebSiteException {

        try {

            // open the account statements page
            final TargoBankAccountStatementsPage page = new TargoBankAccountStatementsPage(this.webClient,
                    this.accountInfo.getCardAccount());

            final Map<Date, WebElement> links = page.getAccountLinks(this.lastStatementDate);

            for (final Entry<Date, WebElement> link : links.entrySet()) {

                final WebElement linkElemet = link.getValue();
                // get the expected file name
                final String href = linkElemet.getAttribute(WebUtils.HTML_TAG_HREF);
                final URI uri = new URI(href); // NOPMD
                final Map<String, String> params = WebUtils.getQueryMap(uri);
                String expectedFileName = params.get("NOM"); //$NON-NLS-1$
                expectedFileName = expectedFileName.replace('+', ' ') + ".pdf"; //$NON-NLS-1$

                final byte[] data = WebUtilsSelenium.getSeleniumPdfAsByteArray(this.webClient, linkElemet,
                        expectedFileName);
                // create an MahoeAccountStatement
                final MahoeAccountStatement statementInfo = new MahoeAccountStatement(link.getKey(), TargoBank.NAME); // NOPMD
                this.addStatement(statementInfo, data);

            }

        } catch (FailingHttpStatusCodeException | URISyntaxException | RemoteException e) {
            Logger.error(I18N.tr("TargoBankWebSite.loadPdfFailedLog", e.getMessage()), e); //$NON-NLS-1$
            throw new WebSiteException(I18N.tr("AccountStatementFinder.downloadFailed"), //$NON-NLS-1$
                    WebSiteExceptionTypes.PAGE_NOT_FOUND, e);
        }

    }

}
