/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.jobs;

import java.rmi.RemoteException;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;

import de.frankmuenster.mahoe.utils.I18N;
import de.willuhn.jameica.hbci.SynchronizeOptions;
import de.willuhn.jameica.hbci.rmi.Konto;
import de.willuhn.jameica.hbci.rmi.KontoauszugInterval;
import de.willuhn.jameica.hbci.server.KontoauszugPdfUtil;
import de.willuhn.jameica.hbci.synchronize.jobs.SynchronizeJob;
import de.willuhn.jameica.hbci.synchronize.jobs.SynchronizeJobKontoauszugPdf;
import de.willuhn.logging.Logger;
import de.willuhn.util.ApplicationException;

/**
 * Abstract class of an account provider to download PDF sheets
 *
 * @author Frank Mnster
 *
 */
public abstract class AbstractMahoeSynchronizeJobProviderKontoauszugPDF extends AbstractMahoeSynchronizeJobProvider {

    /**
     * Standard constructor
     */
    public AbstractMahoeSynchronizeJobProviderKontoauszugPDF() {
        super();
    }

    /**
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    @Override
    public int compareTo(final Object arg0) {
        // ganz am Ende.
        return 9;
    }

    /**
     * @see de.willuhn.jameica.hbci.synchronize.SynchronizeJobProvider#getSynchronizeJobs(de.willuhn.jameica.hbci.rmi.Konto)
     */
    @Override
    public List<SynchronizeJob> getSynchronizeJobs(final Konto konto) {

        final Class<SynchronizeJobKontoauszugPdf> type = SynchronizeJobKontoauszugPdf.class;

        final List<SynchronizeJob> myJobs = new LinkedList<>();
        for (final Konto kto : this.backend.getSynchronizeKonten(konto)) {
            final SynchronizeJobKontoauszugPdf job = getJobFromAccount(type, kto);
            if (job != null) {
                myJobs.add(job);
            }
        }

        return myJobs;
    }

    /**
     * @see AbstractMahoeSynchronizeJobProvider#isJobTypeSupported(Class, Konto)
     */
    @Override
    protected boolean isJobTypeSupported(final Class<? extends SynchronizeJob> type, final Konto account)
            throws RemoteException {

        return SynchronizeJobKontoauszugPdf.class.isAssignableFrom(type) && KontoauszugPdfUtil.supported(account);
    }

    private SynchronizeJobKontoauszugPdf getJobFromAccount(final Class<SynchronizeJobKontoauszugPdf> type,
            final Konto account) {
        SynchronizeJobKontoauszugPdf job = null;

        try {
            // Is Mahoe Backend and account supported?
            if (this.backend.supports(type, account) && this.supports(type, account)) {

                final SynchronizeOptions options = new SynchronizeOptions(account);

                // Sync-Option zum Kontoauszugs-Abruf aktiv?
                if (options.getSyncKontoauszuegePdf() && KontoauszugPdfUtil.supported(account)) {

                    final Date next = KontoauszugInterval.getNextInterval(account);
                    if (next != null && next.before(new Date())) {
                        // erzeugt eine Instanz von
                        // SynchronizeJobKontoauszug
                        job = this.backend.create(type, account);
                        job.setContext(SynchronizeJob.CTX_ENTITY, account);
                    }
                }
            }
        } catch (RemoteException | ApplicationException e) {
            Logger.error(I18N.tr("BshSynchronizeJobProviderKontoauszug.getSynchnizedJobsFailed"), e); //$NON-NLS-1$
        }

        return job;

    }

}
