/*******************************************************************************
 * Copyright 2015 - 2019 fmCreation
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald diese von der
 * Europischen Kommission genehmigt wurden - Folgeversionen der EUPL
 * ("Lizenz"); Sie drfen dieses Werk ausschlielich gem dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 *   https://progs.frankmuenster.de/eupl_v1-2_de
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften gefordert oder in
 * schriftlicher Form vereinbart, wird die unter der Lizenz verbreitete Software
 * "so wie sie ist", OHNE JEGLICHE GEWHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrcklich oder stillschweigend - verbreitet. Die sprachspezifischen
 * Genehmigungen und Beschrnkungen unter der Lizenz sind dem Lizenztext zu
 * entnehmen.
 ******************************************************************************/

package de.frankmuenster.mahoe.utils;

import java.util.Arrays;

/**
 * @author Frank Mnster
 */
public class SecureCharSequence implements CharSequence {

    /**
     * The internally used charter array which can be wiped
     */
    private final char[] value;

    /**
     * Returns a new SecureCharSequence initialised with the given char array.
     *
     * @param value
     *            the charter array to be used for this secure
     *            {@link CharSequence}
     */
    public SecureCharSequence(final char[] value) { // NOPMD

        if (value == null) {
            throw new IllegalArgumentException("Value must not be null"); //$NON-NLS-1$
        }
        this.value = value.clone();
    }

    @Override
    public char charAt(final int index) {

        return this.value[index];
    }

    @Override
    public int length() {

        return this.value.length;
    }

    @Override
    public CharSequence subSequence(final int start, final int end) {

        throw new UnsupportedOperationException();
    }

    /**
     * Wipes the internally used variable to store the char sequence
     */
    public void wipe() {

        Arrays.fill(this.value, '\u0000');
    }

}
