/*******************************************************************************
 * Copyright 2015 - 2018 fmCreation
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they
 * will be approved by the European Commission - subsequent
 * versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the
 * Licence.
 * You may obtain a copy of the Licence at:
 *
 *    https://progs.frankmuenster.de/eupl_v1-2_en/
 *
 * Unless required by applicable law or agreed to in
 * writing, software distributed under the Licence is
 * distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied.
 * See the Licence for the specific language governing
 * permissions and limitations under the Licence.
 ******************************************************************************/

package de.frankmuenster.mahoe.utils.pdfsaver;

/**
 * Exceptions fr den PdfSaver
 *
 * @author Frank Mnster
 */
public class PdfSaverException extends Exception {

    /**
     * Die Serial UID
     */
    private static final long serialVersionUID = -3968621607319744568L;

    /**
     * Der PdfSaverException Typ
     */
    private final PdfSaverExceptionTyp typ;

    /**
     * Erstellt eine neue Exception
     */
    public PdfSaverException() {
	this(null);
    }

    /**
     * Erstellt eine neue Exception mit Nachricht.
     *
     * @param message
     */
    public PdfSaverException(final String message) {
	super(message);
	this.typ = null; // NOPMD
    }

    /**
     * Erstellt eine neue Exception mit Nachricht und Fehlertypen.
     *
     * @param message
     * @param typ
     */
    public PdfSaverException(final String message, final PdfSaverExceptionTyp typ) {
	super(message);
	this.typ = typ;
    }

    /**
     * Erstellt eine neue Exception mit Nachricht und ursprnglichen Fehler.
     *
     * @param message
     * @param cause
     *            der Grund
     */
    public PdfSaverException(final String message, final Throwable cause) {
	super(message, cause);
	this.typ = null; // NOPMD
    }

    /**
     * Liefert den Typ der Exception
     *
     * @return den Typ
     */
    public PdfSaverExceptionTyp getTyp() {

	return this.typ;
    }

}
